@@ -146,14 +146,16 @@ def find_closest_time(prompt_time, subset_time_list):
 def get_distance_from_home(location, info_dict):
     distance_from_home = "bboxNF"  # this means the lsf.json has no bbox for home cluster (i.e., lsf.json recovery error)
     if type(location) != str:
-        distance_from_home_candidate_list = []
-        home_coords = info_dict["home_loc"]
-        for home_coord in home_coords:
-            d_tmp = haversine(location, home_coord)
-            if distance_from_home == "bboxNF":
-                distance_from_home = d_tmp
-            if d_tmp < distance_from_home:
-                distance_from_home = d_tmp
+        if "home_loc" in info_dict:
+            home_coords = info_dict["home_loc"]
+            for home_coord in home_coords:
+                d_tmp = haversine(location, home_coord)
+                if distance_from_home == "bboxNF":
+                    distance_from_home = d_tmp
+                if d_tmp < distance_from_home:
+                    distance_from_home = d_tmp
+        else:
+            distance_from_home = "jsonNF"
 
     return distance_from_home
 
@@ -193,7 +195,7 @@ def match_feature(prompt_local_datetime_series, df_logs_combined, info_dict, par
         if p_id_exist_info_dict:
             distance_from_home = get_distance_from_home(location, info_dict[participant_id])
         else:
-            distance_from_home = "JsonNF"  # this means this participant has no recovered lsf.json
+            distance_from_home = "pidNF"  # this means this participant has no recovered lsf.json
         distance_from_home_list.append(distance_from_home)
 
     return matched_location_list, matched_time_list, distance_from_home_list
