@@ -59,25 +59,29 @@ def find_closest_time(prompt_time, subset_time_list):
     return pos
 
 
-def get_mims_summary(min_before, prompt_time, closest_times, df_logs_combined):
+def get_mims_summary(sec_before, prompt_time, closest_times, df_logs_combined):
     mims_summary = 0
     num_readings = 0
     start_time = None
     for matched_idx in closest_times:
         closest_time = df_logs_combined.loc[matched_idx, "TIME_DATETIME"]
-        if get_min_diff(prompt_time, closest_time) < (min_before + 1):
+        if get_min_diff(prompt_time, closest_time) <= (sec_before//60 + 1):
             mims_min = df_logs_combined.loc[matched_idx, "MIMS_UNIT"]
             if mims_min != -0.01: # mims value -0.01 means cannot be computed
                 mims_summary += mims_min
                 num_readings += 1
             start_time = closest_time
+        else:
+            if start_time is None:
+                mims_summary = "OB"
+            break
     return mims_summary, num_readings, start_time
 
 
 def match_feature(prompt_local_datetime_series, df_logs_combined):
     print("     --- start matching")
     # Aggregating minutes before prompt time
-    min_before_list = [60*x for x in list(range(1, 11))]
+    sec_before_list = [60*x for x in list(range(1, 11))]
 
     mims_summary_list = []
     start_time_list = []
@@ -92,18 +96,19 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
         # prompt_date = prompt_time.date()
 
         if df_logs_combined.shape[0] == 0:
-            matched_mims_summary_list = [np.nan] * len(min_before_list)
-            matched_readings_list = [np.nan] * len(min_before_list)
-            matched_start_time_list = [np.nan] * len(min_before_list)
+            matched_mims_summary_list = [np.nan] * len(sec_before_list)
+            matched_readings_list = [np.nan] * len(sec_before_list)
+            matched_start_time_list = [np.nan] * len(sec_before_list)
         else:
             subset_time_list = list(df_logs_combined["TIME_DATETIME"])
             pos = find_closest_time(prompt_time, subset_time_list)
-            for min_before in min_before_list:
+
+            for sec_before in sec_before_list:
                 closest_times = []
-                for i in range(min_before):
+                for i in range(sec_before):
                     closest_times.append(pos - 1 - i)
                 closest_times = [x for x in closest_times if x >= 0]
-                mims_summary, readings, start_time = get_mims_summary(min_before, prompt_time, closest_times,
+                mims_summary, readings, start_time = get_mims_summary(sec_before, prompt_time, closest_times,
                                                                       df_logs_combined)
                 matched_mims_summary_list.append(mims_summary)
                 matched_readings_list.append(readings)
@@ -117,11 +122,11 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
     start_time_df = pd.DataFrame(list(map(np.ravel, start_time_list)))
 
     df = pd.DataFrame()
-    for min_before in min_before_list:
-        col = int(min_before//60 - 1)
-        df = pd.concat([df, mims_summary_df[col].rename("mims_summary_" + str(min_before//60) + "min")], axis=1)
-        df = pd.concat([df, readings_df[col].rename("num_readings_" + str(min_before//60) + "min")], axis=1)
-        df = pd.concat([df, start_time_df[col].rename("start_time_" + str(min_before//60) + "min")], axis=1)
+    for sec_before in sec_before_list:
+        col = int(sec_before//60 - 1)
+        df = pd.concat([df, mims_summary_df[col].rename("mims_summary_" + str(sec_before//60) + "min")], axis=1)
+        df = pd.concat([df, readings_df[col].rename("num_readings_" + str(sec_before//60) + "min")], axis=1)
+        df = pd.concat([df, start_time_df[col].rename("start_time_" + str(sec_before//60) + "min")], axis=1)
 
 
     return df
