@@ -35,7 +35,7 @@ def read_json(json_path):
     return data
 
 def convert_radians_to_degrees(loc):
-    if loc < 7:
+    if abs(loc) < 7:
         loc = degrees(loc)
     return round(loc, 5)
 
